@@ -1,2 +1,5 @@
+"""
+Data engine API (deprecated).
+"""
 from algora.api.service.data_engine.asynchronous import async_analyze_data, async_transform_data
 from algora.api.service.data_engine.synchronous import analyze_data, transform_data
