@@ -52,7 +52,8 @@ class EnvironmentConfig:
     """
     urls: dict = {
         'algora': 'https://api.algoralabs.com',
-        'keycloak': 'https://auth.algoralabs.com/auth/admin/realms/production',
+        'keycloak_admin': 'https://auth.algoralabs.com/auth/admin/realms/production',
+        'keycloak': 'https://auth.algoralabs.com/auth/realms/production',
         'fred': 'https://api.stlouisfed.org/fred'
     }
     auth_config: Auth = Auth()
@@ -62,7 +63,7 @@ class EnvironmentConfig:
         Get base URL given key.
 
         Args:
-            key (str): URL key; 'algora', 'keycloak' or 'fred'
+            key (str): URL key; 'algora', 'keycloak_admin', 'keycloak' or 'fred'
 
         Returns:
             str: Base URL string
